@@ -1,6 +1,5 @@
 import paramiko
-
-from entity.entSftpFile import entSftpFile
+from bgutils.mysqlUtil import mysqlUtil
 
 
 class ftpUtil:
@@ -40,8 +39,11 @@ class ftpUtil:
 
         try:
             #记录文件列表
-            ent = entSftpFile(local_path,self.__url_head+remote_file,stud) #filename,url,stud
-            self.__mutil.sftp_file_ins(ent)
+            # item = entSftpFile()
+            # item['filename'] = local_path
+            # item['url'] = self.__url_head+remote_file
+            # item['stud'] = stud
+            self.__mutil.sftp_file_ins(local_path,self.__url_head+remote_file,stud)
         except Exception as ex:
             print("日志记录出现如下异常%s"%ex)
 
